@@ -3,6 +3,8 @@ import json
 import yaml
 import time
 import cv2
+from PIL import Image
+import numpy as np
 import logging
 
 from .config import model_registry
@@ -32,14 +34,15 @@ class Classification(FileUtils):
         self.task_type = 0
         if not modelId is None:
             saved_model_list = os.listdir('modelfile')
-            saved_model_list = [item for item in saved_model_list if '-' in item and
+            saved_model_list = [item for item in saved_model_list if '-' in item and 'pth' in item and \
                                                                      (item.split('-')[0]==modelId or \
                                                                      eval(item.split('-')[0])==modelId)]
             if len(saved_model_list):
                 try:
-                    model_path   = saved_model_list[0]
-                    backbone     = model_path.split('-')[1]
-                    input_shape  = eval(model_path.split('-')[2])
+                    model_name   = saved_model_list[0]
+                    model_path   = f'modelfile/{model_name}'
+                    backbone     = model_name.split('-')[1]
+                    input_shape  = eval(model_name.split('-')[2])
                     classes_path = f'modelfile/{modelId}-classes.txt'
                     cuda         = False
                     self.model   = load_cls_model(model_path=model_path,backbone=backbone,input_shape=input_shape,
@@ -126,7 +129,7 @@ class Classification(FileUtils):
         try:
             img_list = sorted(kwargs.items(), key=lambda x: x[0])
             img_list = [item[1] for item in img_list]
-            image = cv2.hconcat(img_list)
+            image = Image.fromarray(cv2.cvtColor(cv2.hconcat(img_list),cv2.COLOR_BGR2RGB))
             pred_lbl,pred_conf = self.model.detect_image_cls(image)
             return generateResult(confidence, label)
         except Exception as e:
